@@ -13,7 +13,7 @@ use 5.00800;
 use Carp 'croak';
 use Scalar::Util;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(encoded_string build_mt render_mt);
 our %EXPORT_TAGS = (
@@ -90,6 +90,7 @@ sub _build {
     # Compile
     my @lines;
     my $last_was_code;
+    my $last_text;
     for my $line (@{$self->{tree}}) {
 
         # New line
@@ -98,6 +99,11 @@ sub _build {
             my $type  = $line->[$j];
             my $value = $line->[$j + 1];
 
+            if ($type ne 'text' && defined $last_text) {
+                $lines[-1] = "\$_MT .=\"$last_text\";";
+                undef $last_text;
+            }
+            
             # Need to fix line ending?
             my $newline = chomp $value;
 
@@ -114,7 +120,7 @@ sub _build {
                 $value = quotemeta($value);
                 $value .= '\n' if $newline;
 
-                $lines[-1] .= "\$_MT .= \"" . $value . "\";";
+                $last_text = defined $last_text ? "$last_text$value" : $value;
             }
 
             # Code
@@ -135,6 +141,10 @@ sub _build {
     if ($last_was_code) {
         $lines[-1] .= "\n;";
     }
+    # add last text line(s)
+    if (defined $last_text) {
+        $lines[-1] .= "\$_MT .=\"$last_text\";";
+    }
     
     # Wrap
     $lines[0]   = q/sub { my $_MT = ''; local $/ . $self->{package_name} . q/::_MTREF = \$_MT; my $_MT_T = '';/ . (@lines ? $lines[0] : '');
